@@ -184,6 +184,9 @@ def from_dagster_event_record(event_record, pipeline_name):
         GrapheneMaterializationEvent,
         GrapheneObjectStoreOperationEvent,
         GrapheneObservationEvent,
+        GrapheneResourceInitFailureEvent,
+        GrapheneResourceInitStartedEvent,
+        GrapheneResourceInitSuccessEvent,
         GrapheneRunCanceledEvent,
         GrapheneRunCancelingEvent,
         GrapheneRunDequeuedEvent,
@@ -193,6 +196,8 @@ def from_dagster_event_record(event_record, pipeline_name):
         GrapheneRunStartingEvent,
         GrapheneRunSuccessEvent,
         GrapheneStepExpectationResultEvent,
+        GrapheneStepWorkerStartedEvent,
+        GrapheneStepWorkerStartingEvent,
     )
 
     # Lots of event types. Pylint thinks there are too many branches
@@ -336,8 +341,8 @@ def from_dagster_event_record(event_record, pipeline_name):
             error=GraphenePythonError(dagster_event.engine_event_data.error)
             if dagster_event.engine_event_data.error
             else None,
-            marker_start=dagster_event.engine_event_data.marker_start,
-            marker_end=dagster_event.engine_event_data.marker_end,
+            markerStart=dagster_event.engine_event_data.marker_start,
+            markerEnd=dagster_event.engine_event_data.marker_end,
             **basic_params,
         )
     elif dagster_event.event_type == DagsterEventType.HOOK_COMPLETED:
@@ -355,6 +360,42 @@ def from_dagster_event_record(event_record, pipeline_name):
             pid=dagster_event.pid,
             **basic_params,
         )
+    elif dagster_event.event_type == DagsterEventType.STEP_WORKER_STARTING:
+        return GrapheneStepWorkerStartingEvent(
+            metadataEntries=_to_metadata_entries(dagster_event.engine_event_data.metadata_entries),
+            markerStart=dagster_event.engine_event_data.marker_start,
+            markerEnd=dagster_event.engine_event_data.marker_end,
+            **basic_params,
+        )
+    elif dagster_event.event_type == DagsterEventType.STEP_WORKER_STARTED:
+        return GrapheneStepWorkerStartedEvent(
+            metadataEntries=_to_metadata_entries(dagster_event.engine_event_data.metadata_entries),
+            markerStart=dagster_event.engine_event_data.marker_start,
+            markerEnd=dagster_event.engine_event_data.marker_end,
+            **basic_params,
+        )
+    elif dagster_event.event_type == DagsterEventType.RESOURCE_INIT_STARTED:
+        return GrapheneResourceInitStartedEvent(
+            metadataEntries=_to_metadata_entries(dagster_event.engine_event_data.metadata_entries),
+            markerStart=dagster_event.engine_event_data.marker_start,
+            markerEnd=dagster_event.engine_event_data.marker_end,
+            **basic_params,
+        )
+    elif dagster_event.event_type == DagsterEventType.RESOURCE_INIT_SUCCESS:
+        return GrapheneResourceInitSuccessEvent(
+            metadataEntries=_to_metadata_entries(dagster_event.engine_event_data.metadata_entries),
+            markerStart=dagster_event.engine_event_data.marker_start,
+            markerEnd=dagster_event.engine_event_data.marker_end,
+            **basic_params,
+        )
+    elif dagster_event.event_type == DagsterEventType.RESOURCE_INIT_FAILURE:
+        return GrapheneResourceInitFailureEvent(
+            metadataEntries=_to_metadata_entries(dagster_event.engine_event_data.metadata_entries),
+            markerStart=dagster_event.engine_event_data.marker_start,
+            markerEnd=dagster_event.engine_event_data.marker_end,
+            error=GraphenePythonError(dagster_event.engine_event_data.error),
+            **basic_params,
+        )
     else:
         raise Exception(
             "Unknown DAGSTER_EVENT type {inner_type} found in logs".format(
