@@ -7,6 +7,7 @@ import dagster._check as check
 from dagster.core.events import DagsterEventType, EngineEventData
 from dagster.core.instance import DagsterInstance
 from dagster.core.storage.compute_log_manager import ComputeIOType
+from dagster.core.storage.event_log.base import EventLogCursor
 from dagster.core.storage.pipeline_run import PipelineRunStatus, RunsFilter
 from dagster.serdes import serialize_dagster_namedtuple
 from dagster.utils.error import serializable_error_info_from_exc_info
@@ -70,11 +71,12 @@ def terminate_pipeline_execution(instance, run_id, terminate_policy):
     run = record.pipeline_run
     graphene_run = GrapheneRun(record)
 
-    valid_status = not run.is_finished and (
-        force_mark_as_canceled
-        or (run.status == PipelineRunStatus.STARTED or run.status == PipelineRunStatus.QUEUED)
+    can_cancel_run = (
+        run.status == PipelineRunStatus.STARTED or run.status == PipelineRunStatus.QUEUED
     )
 
+    valid_status = not run.is_finished and (force_mark_as_canceled or can_cancel_run)
+
     if not valid_status:
         return GrapheneTerminateRunFailure(
             run=graphene_run,
@@ -85,7 +87,7 @@ def terminate_pipeline_execution(instance, run_id, terminate_policy):
 
     if force_mark_as_canceled:
         try:
-            if instance.run_coordinator and instance.run_coordinator.can_cancel_run(run_id):
+            if instance.run_coordinator and can_cancel_run:
                 instance.run_coordinator.cancel_run(run_id)
         except:
             instance.report_engine_event(
@@ -98,11 +100,7 @@ def terminate_pipeline_execution(instance, run_id, terminate_policy):
             )
         return _force_mark_as_canceled(instance, run_id)
 
-    if (
-        instance.run_coordinator
-        and instance.run_coordinator.can_cancel_run(run_id)
-        and instance.run_coordinator.cancel_run(run_id)
-    ):
+    if instance.run_coordinator and can_cancel_run and instance.run_coordinator.cancel_run(run_id):
         return GrapheneTerminateRunSuccess(graphene_run)
 
     return GrapheneTerminateRunFailure(
@@ -125,7 +123,7 @@ def delete_pipeline_run(graphene_info, run_id):
     return GrapheneDeletePipelineRunSuccess(run_id)
 
 
-def get_pipeline_run_observable(graphene_info, run_id, after=None):
+def get_pipeline_run_observable(graphene_info, run_id, cursor=None):
     from ...schema.pipelines.pipeline import GrapheneRun
     from ...schema.pipelines.subscription import (
         GraphenePipelineRunLogsSubscriptionFailure,
@@ -135,7 +133,7 @@ def get_pipeline_run_observable(graphene_info, run_id, after=None):
 
     check.inst_param(graphene_info, "graphene_info", ResolveInfo)
     check.str_param(run_id, "run_id")
-    check.opt_int_param(after, "after")
+    check.opt_str_param(cursor, "cursor")
     instance = graphene_info.context.instance
     records = instance.get_run_records(RunsFilter(run_ids=[run_id]))
 
@@ -154,17 +152,18 @@ def get_pipeline_run_observable(graphene_info, run_id, after=None):
     run = record.pipeline_run
 
     def _handle_events(payload):
-        events, loading_past = payload
+        events, loading_past, cursor = payload
         return GraphenePipelineRunLogsSubscriptionSuccess(
             run=GrapheneRun(record),
             messages=[from_event_record(event, run.pipeline_name) for event in events],
             hasMorePastEvents=loading_past,
+            cursor=cursor,
         )
 
     # pylint: disable=E1101
-    return Observable.create(
-        PipelineRunObservableSubscribe(instance, run_id, after_cursor=after)
-    ).map(_handle_events)
+    return Observable.create(PipelineRunObservableSubscribe(instance, run_id, cursor=cursor)).map(
+        _handle_events
+    )
 
 
 def get_compute_log_observable(graphene_info, run_id, step_key, io_type, cursor=None):
