@@ -1,8 +1,8 @@
-# pylint: disable=missing-graphene-docstring
 from typing import TYPE_CHECKING, List, Optional, Sequence, Union
 
 import graphene
 from dagster_graphql.implementation.events import iterate_metadata_entries
+from dagster_graphql.schema.config_types import GrapheneConfigTypeField
 from dagster_graphql.schema.metadata import GrapheneMetadataEntry
 from dagster_graphql.schema.solids import (
     GrapheneCompositeSolidDefinition,
@@ -24,7 +24,7 @@ from . import external
 from .asset_key import GrapheneAssetKey
 from .errors import GrapheneAssetNotFoundError
 from .logs.events import GrapheneMaterializationEvent
-from .pipelines.pipeline import GrapheneMaterializationCount, GraphenePipeline
+from .pipelines.pipeline import GrapheneMaterializationCount, GraphenePipeline, GrapheneRun
 from .util import non_null_list
 
 if TYPE_CHECKING:
@@ -76,6 +76,17 @@ class GrapheneAssetDependency(graphene.ObjectType):
         )
 
 
+class GrapheneAssetLatestInfo(graphene.ObjectType):
+    assetKey = graphene.NonNull(GrapheneAssetKey)
+    latestMaterialization = graphene.Field(GrapheneMaterializationEvent)
+    unstartedRunIds = non_null_list(graphene.String)
+    inProgressRunIds = non_null_list(graphene.String)
+    latestRun = graphene.Field(GrapheneRun)
+
+    class Meta:
+        name = "AssetLatestInfo"
+
+
 class GrapheneAssetNode(graphene.ObjectType):
 
     # NOTE: properties/resolvers are listed alphabetically
@@ -87,6 +98,7 @@ class GrapheneAssetNode(graphene.ObjectType):
         limit=graphene.Int(),
     )
     computeKind = graphene.String()
+    configField = graphene.Field(GrapheneConfigTypeField)
     dependedBy = non_null_list(GrapheneAssetDependency)
     dependedByKeys = non_null_list(GrapheneAssetKey)
     dependencies = non_null_list(GrapheneAssetDependency)
@@ -108,6 +120,7 @@ class GrapheneAssetNode(graphene.ObjectType):
     partitionKeys = non_null_list(graphene.String)
     partitionDefinition = graphene.String()
     repository = graphene.NonNull(lambda: external.GrapheneRepository)
+    groupName = graphene.String()
 
     class Meta:
         name = "AssetNode"
@@ -143,6 +156,7 @@ class GrapheneAssetNode(graphene.ObjectType):
             assetKey=external_asset_node.asset_key,
             description=external_asset_node.op_description,
             opName=external_asset_node.op_name,
+            groupName=external_asset_node.group_name,
         )
 
     @property
@@ -157,6 +171,19 @@ class GrapheneAssetNode(graphene.ObjectType):
     def external_asset_node(self) -> ExternalAssetNode:
         return self._external_asset_node
 
+    def get_op_definition(
+        self,
+    ) -> Optional[Union[GrapheneSolidDefinition, GrapheneCompositeSolidDefinition]]:
+        if len(self._external_asset_node.job_names) >= 1:
+            pipeline_name = self._external_asset_node.job_names[0]
+            pipeline = self._external_repository.get_full_external_pipeline(pipeline_name)
+            op_key = (
+                self._external_asset_node.node_definition_name or self._external_asset_node.op_name
+            )
+            return build_solid_definition(pipeline, op_key)
+        else:
+            return None
+
     def get_partition_keys(self) -> Sequence[str]:
         # TODO: Add functionality for dynamic partitions definition
         partitions_def_data = self._external_asset_node.partitions_def_data
@@ -213,6 +240,15 @@ class GrapheneAssetNode(graphene.ObjectType):
             )
         ]
 
+    # TODO: Prob want a more efficient way of resolving this
+    def resolve_configField(self, _graphene_info) -> Optional[GrapheneConfigTypeField]:
+        op = self.get_op_definition()
+        return (
+            op.resolve_config_field(_graphene_info)
+            if op and isinstance(op, GrapheneSolidDefinition)
+            else None
+        )
+
     def resolve_computeKind(self, _graphene_info) -> Optional[str]:
         return self._external_asset_node.compute_kind
 
@@ -365,12 +401,7 @@ class GrapheneAssetNode(graphene.ObjectType):
     def resolve_op(
         self, _graphene_info
     ) -> Optional[Union[GrapheneSolidDefinition, GrapheneCompositeSolidDefinition]]:
-        if len(self._external_asset_node.job_names) >= 1:
-            pipeline_name = self._external_asset_node.job_names[0]
-            pipeline = self._external_repository.get_full_external_pipeline(pipeline_name)
-            return build_solid_definition(pipeline, self._external_asset_node.op_name)
-        else:
-            return None
+        return self.get_op_definition()
 
     def resolve_opNames(self, _graphene_info) -> Sequence[str]:
         return self._external_asset_node.op_names or []
@@ -393,6 +424,14 @@ class GrapheneAssetNode(graphene.ObjectType):
         )
 
 
+class GrapheneAssetGroup(graphene.ObjectType):
+    groupName = graphene.NonNull(graphene.String)
+    assetKeys = non_null_list(GrapheneAssetKey)
+
+    class Meta:
+        name = "AssetGroup"
+
+
 class GrapheneAssetNodeOrError(graphene.Union):
     class Meta:
         types = (GrapheneAssetNode, GrapheneAssetNotFoundError)
