@@ -5,7 +5,7 @@ import graphene
 import pendulum
 import yaml
 
-from dagster import check
+import dagster._check as check
 from dagster.core.definitions.schedule_definition import ScheduleExecutionData
 from dagster.core.definitions.sensor_definition import RunRequest
 from dagster.core.scheduler.instigation import (
