@@ -1,4 +1,3 @@
-# pylint: disable=missing-graphene-docstring
 import graphene
 
 import dagster._check as check
@@ -31,7 +30,7 @@ class GrapheneMessageEvent(graphene.Interface):
 
 
 class GrapheneDisplayableEvent(graphene.Interface):
-    label = graphene.NonNull(graphene.String)
+    label = graphene.String()
     description = graphene.String()
     metadataEntries = non_null_list(GrapheneMetadataEntry)
 
@@ -39,6 +38,21 @@ class GrapheneDisplayableEvent(graphene.Interface):
         name = "DisplayableEvent"
 
 
+class GrapheneMarkerEvent(graphene.Interface):
+    markerStart = graphene.String()
+    markerEnd = graphene.String()
+
+    class Meta:
+        name = "MarkerEvent"
+
+
+class GrapheneErrorEvent(graphene.Interface):
+    error = graphene.Field(GraphenePythonError)
+
+    class Meta:
+        name = "ErrorEvent"
+
+
 class GrapheneMissingRunIdErrorEvent(graphene.ObjectType):
     invalidRunId = graphene.NonNull(graphene.String)
 
@@ -102,10 +116,8 @@ class GrapheneRunSuccessEvent(graphene.ObjectType):
 
 
 class GrapheneRunFailureEvent(graphene.ObjectType):
-    error = graphene.Field(GraphenePythonError)
-
     class Meta:
-        interfaces = (GrapheneMessageEvent, GrapheneRunEvent)
+        interfaces = (GrapheneMessageEvent, GrapheneRunEvent, GrapheneErrorEvent)
         name = "RunFailureEvent"
 
 
@@ -148,11 +160,10 @@ class GrapheneExecutionStepRestartEvent(graphene.ObjectType):
 
 
 class GrapheneExecutionStepUpForRetryEvent(graphene.ObjectType):
-    error = graphene.Field(GraphenePythonError)
     secondsToWait = graphene.Field(graphene.Int)
 
     class Meta:
-        interfaces = (GrapheneMessageEvent, GrapheneStepEvent)
+        interfaces = (GrapheneMessageEvent, GrapheneStepEvent, GrapheneErrorEvent)
         name = "ExecutionStepUpForRetryEvent"
 
 
@@ -248,10 +259,9 @@ class GrapheneExecutionStepSuccessEvent(graphene.ObjectType):
 
 class GrapheneExecutionStepFailureEvent(graphene.ObjectType):
     class Meta:
-        interfaces = (GrapheneMessageEvent, GrapheneStepEvent)
+        interfaces = (GrapheneMessageEvent, GrapheneStepEvent, GrapheneErrorEvent)
         name = "ExecutionStepFailureEvent"
 
-    error = graphene.Field(GraphenePythonError)
     errorSource = graphene.Field(graphene.Enum.from_enum(ErrorSource))
     failureMetadata = graphene.Field(GrapheneFailureMetadata)
 
@@ -270,11 +280,9 @@ class GrapheneHookSkippedEvent(graphene.ObjectType):
 
 class GrapheneHookErroredEvent(graphene.ObjectType):
     class Meta:
-        interfaces = (GrapheneMessageEvent, GrapheneStepEvent)
+        interfaces = (GrapheneMessageEvent, GrapheneStepEvent, GrapheneErrorEvent)
         name = "HookErroredEvent"
 
-    error = graphene.Field(GraphenePythonError)
-
 
 class GrapheneLogsCapturedEvent(graphene.ObjectType):
     class Meta:
@@ -433,12 +441,70 @@ class GrapheneObjectStoreOperationEvent(graphene.ObjectType):
 
 class GrapheneEngineEvent(graphene.ObjectType):
     class Meta:
-        interfaces = (GrapheneMessageEvent, GrapheneDisplayableEvent, GrapheneStepEvent)
+        interfaces = (
+            GrapheneMessageEvent,
+            GrapheneDisplayableEvent,
+            GrapheneStepEvent,
+            GrapheneMarkerEvent,
+            GrapheneErrorEvent,
+        )
         name = "EngineEvent"
 
-    error = graphene.Field(GraphenePythonError)
-    marker_start = graphene.Field(graphene.String)
-    marker_end = graphene.Field(graphene.String)
+
+class GrapheneResourceInitFailureEvent(graphene.ObjectType):
+    class Meta:
+        interfaces = (
+            GrapheneMessageEvent,
+            GrapheneDisplayableEvent,
+            GrapheneStepEvent,
+            GrapheneMarkerEvent,
+            GrapheneErrorEvent,
+        )
+        name = "ResourceInitFailureEvent"
+
+
+class GrapheneResourceInitStartedEvent(graphene.ObjectType):
+    class Meta:
+        interfaces = (
+            GrapheneMessageEvent,
+            GrapheneDisplayableEvent,
+            GrapheneStepEvent,
+            GrapheneMarkerEvent,
+        )
+        name = "ResourceInitStartedEvent"
+
+
+class GrapheneResourceInitSuccessEvent(graphene.ObjectType):
+    class Meta:
+        interfaces = (
+            GrapheneMessageEvent,
+            GrapheneDisplayableEvent,
+            GrapheneStepEvent,
+            GrapheneMarkerEvent,
+        )
+        name = "ResourceInitSuccessEvent"
+
+
+class GrapheneStepWorkerStartedEvent(graphene.ObjectType):
+    class Meta:
+        interfaces = (
+            GrapheneMessageEvent,
+            GrapheneDisplayableEvent,
+            GrapheneStepEvent,
+            GrapheneMarkerEvent,
+        )
+        name = "StepWorkerStartedEvent"
+
+
+class GrapheneStepWorkerStartingEvent(graphene.ObjectType):
+    class Meta:
+        interfaces = (
+            GrapheneMessageEvent,
+            GrapheneDisplayableEvent,
+            GrapheneStepEvent,
+            GrapheneMarkerEvent,
+        )
+        name = "StepWorkerStartingEvent"
 
 
 class GrapheneStepExpectationResultEvent(graphene.ObjectType):
@@ -462,6 +528,9 @@ class GrapheneDagsterRunEvent(graphene.Union):
             GrapheneExecutionStepUpForRetryEvent,
             GrapheneExecutionStepRestartEvent,
             GrapheneLogMessageEvent,
+            GrapheneResourceInitFailureEvent,
+            GrapheneResourceInitStartedEvent,
+            GrapheneResourceInitSuccessEvent,
             GrapheneRunFailureEvent,
             GrapheneRunStartEvent,
             GrapheneRunEnqueuedEvent,
@@ -470,6 +539,8 @@ class GrapheneDagsterRunEvent(graphene.Union):
             GrapheneRunCancelingEvent,
             GrapheneRunCanceledEvent,
             GrapheneRunSuccessEvent,
+            GrapheneStepWorkerStartedEvent,
+            GrapheneStepWorkerStartingEvent,
             GrapheneHandledOutputEvent,
             GrapheneLoadedInputEvent,
             GrapheneLogsCapturedEvent,
