@@ -1,4 +1,3 @@
-# pylint: disable=missing-graphene-docstring
 import graphene
 
 import dagster._check as check
@@ -6,7 +5,7 @@ import dagster._check as check
 
 class GraphenePermission(graphene.ObjectType):
     class Meta:
-        "Permission"
+        name = "Permission"
 
     permission = graphene.NonNull(graphene.String)
     value = graphene.NonNull(graphene.Boolean)
