@@ -1,5 +1,6 @@
 import graphene
-from dagster import check
+
+import dagster._check as check
 from dagster.core.snap import ConfigSchemaSnapshot, ModeDefSnap
 
 from ..util import non_null_list
