@@ -1,6 +1,9 @@
-# pylint: disable=missing-graphene-docstring
+from typing import List
+
 import graphene
 import yaml
+from dagster_graphql.implementation.events import iterate_metadata_entries
+from dagster_graphql.schema.metadata import GrapheneMetadataEntry
 
 import dagster._check as check
 from dagster.core.events import DagsterEventType
@@ -29,7 +32,6 @@ from ..logs.events import (
     GrapheneObservationEvent,
     GrapheneRunStepStats,
 )
-from ..paging import GrapheneCursor
 from ..repository_origin import GrapheneRepositoryOrigin
 from ..runs import GrapheneRunConfigData
 from ..schedules.schedules import GrapheneSchedule
@@ -168,6 +170,21 @@ class GrapheneAsset(graphene.ObjectType):
         ]
 
 
+class GrapheneEventConnection(graphene.ObjectType):
+    class Meta:
+        name = "EventConnection"
+
+    events = non_null_list(GrapheneDagsterRunEvent)
+    cursor = graphene.NonNull(graphene.String)
+    hasMore = graphene.NonNull(graphene.Boolean)
+
+
+class GrapheneEventConnectionOrError(graphene.Union):
+    class Meta:
+        types = (GrapheneEventConnection, GrapheneRunNotFoundError, GraphenePythonError)
+        name = "EventConnectionOrError"
+
+
 class GraphenePipelineRun(graphene.Interface):
     id = graphene.NonNull(graphene.ID)
     runId = graphene.NonNull(graphene.String)
@@ -198,9 +215,9 @@ class GraphenePipelineRun(graphene.Interface):
     parentRunId = graphene.Field(graphene.String)
     canTerminate = graphene.NonNull(graphene.Boolean)
     assets = non_null_list(GrapheneAsset)
-    events = graphene.Field(
-        non_null_list(GrapheneDagsterRunEvent),
-        after=graphene.Argument(GrapheneCursor),
+    eventConnection = graphene.Field(
+        graphene.NonNull(GrapheneEventConnection),
+        afterCursor=graphene.Argument(graphene.String),
     )
 
     class Meta:
@@ -240,9 +257,9 @@ class GrapheneRun(graphene.ObjectType):
     canTerminate = graphene.NonNull(graphene.Boolean)
     assetMaterializations = non_null_list(GrapheneMaterializationEvent)
     assets = non_null_list(GrapheneAsset)
-    events = graphene.Field(
-        non_null_list(GrapheneDagsterRunEvent),
-        after=graphene.Argument(GrapheneCursor),
+    eventConnection = graphene.Field(
+        graphene.NonNull(GrapheneEventConnection),
+        afterCursor=graphene.Argument(graphene.String),
     )
     startTime = graphene.Float()
     endTime = graphene.Float()
@@ -354,11 +371,14 @@ class GrapheneRun(graphene.ObjectType):
     def run_id(self):
         return self.runId
 
-    def resolve_canTerminate(self, graphene_info):
+    def resolve_canTerminate(self, _graphene_info):
         # short circuit if the pipeline run is in a terminal state
         if self._pipeline_run.is_finished:
             return False
-        return graphene_info.context.instance.run_coordinator.can_cancel_run(self.run_id)
+        return (
+            self._pipeline_run.status == PipelineRunStatus.QUEUED
+            or self._pipeline_run.status == PipelineRunStatus.STARTED
+        )
 
     def resolve_assets(self, graphene_info):
         return get_assets_for_run_id(graphene_info, self.run_id)
@@ -372,9 +392,16 @@ class GrapheneRun(graphene.ObjectType):
             )
         ]
 
-    def resolve_events(self, graphene_info, after=-1):
-        events = graphene_info.context.instance.logs_after(self.run_id, cursor=after)
-        return [from_event_record(event, self._pipeline_run.pipeline_name) for event in events]
+    def resolve_eventConnection(self, graphene_info, afterCursor=None):
+        conn = graphene_info.context.instance.get_records_for_run(self.run_id, cursor=afterCursor)
+        return GrapheneEventConnection(
+            events=[
+                from_event_record(record.event_log_entry, self._pipeline_run.pipeline_name)
+                for record in conn.records
+            ],
+            cursor=conn.cursor,
+            hasMore=conn.has_more,
+        )
 
     def _get_run_record(self, instance):
         if not self._run_record:
@@ -434,6 +461,7 @@ class GrapheneIPipelineSnapshotMixin:
         handleID=graphene.Argument(graphene.NonNull(graphene.String)),
     )
     tags = non_null_list(GraphenePipelineTag)
+    metadata_entries = non_null_list(GrapheneMetadataEntry)
     runs = graphene.Field(
         non_null_list(GrapheneRun),
         cursor=graphene.String(),
@@ -535,6 +563,10 @@ class GrapheneIPipelineSnapshotMixin:
             for key, value in represented_pipeline.pipeline_snapshot.tags.items()
         ]
 
+    def resolve_metadata_entries(self, _graphene_info) -> List[GrapheneMetadataEntry]:
+        represented_pipeline = self.get_represented_pipeline()
+        return list(iterate_metadata_entries(represented_pipeline.pipeline_snapshot.metadata))
+
     def resolve_solidSelection(self, _graphene_info):
         return self.get_represented_pipeline().solid_selection
 
@@ -594,6 +626,7 @@ class GrapheneIPipelineSnapshot(graphene.Interface):
         handleID=graphene.Argument(graphene.NonNull(graphene.String)),
     )
     tags = non_null_list(GraphenePipelineTag)
+    metadata_entries = non_null_list(GrapheneMetadataEntry)
     runs = graphene.Field(
         non_null_list(GrapheneRun),
         cursor=graphene.String(),
@@ -785,20 +818,3 @@ class GrapheneRunOrError(graphene.Union):
     class Meta:
         types = (GrapheneRun, GrapheneRunNotFoundError, GraphenePythonError)
         name = "RunOrError"
-
-
-class GrapheneInProgressRunsByStep(graphene.ObjectType):
-    stepKey = graphene.NonNull(graphene.String)
-    unstartedRuns = non_null_list(GrapheneRun)
-    inProgressRuns = non_null_list(GrapheneRun)
-
-    class Meta:
-        name = "InProgressRunsByStep"
-
-
-class GrapheneLatestRun(graphene.ObjectType):
-    stepKey = graphene.NonNull(graphene.String)
-    run = graphene.Field(GrapheneRun)
-
-    class Meta:
-        name = "LatestRun"
