@@ -1,6 +1,6 @@
 import graphene
 
-from dagster import check
+import dagster._check as check
 from dagster.core.host_representation import ExternalRepositoryOrigin
 
 from .util import non_null_list
