@@ -1,4 +1,3 @@
-# pylint: disable=missing-graphene-docstring
 import graphene
 
 import dagster._check as check
@@ -6,7 +5,12 @@ from dagster.core.host_representation import RepresentedPipeline
 
 from ..implementation.run_config_schema import resolve_is_run_config_valid
 from .config_types import GrapheneConfigType, to_config_type
-from .errors import GrapheneModeNotFoundError, GraphenePipelineNotFoundError, GraphenePythonError
+from .errors import (
+    GrapheneInvalidSubsetError,
+    GrapheneModeNotFoundError,
+    GraphenePipelineNotFoundError,
+    GraphenePythonError,
+)
 from .pipelines.config_result import GraphenePipelineConfigValidationResult
 from .runs import GrapheneRunConfigData, parse_run_config_input
 from .util import non_null_list
@@ -76,14 +80,12 @@ class GrapheneRunConfigSchema(graphene.ObjectType):
             graphene_info,
             self._represented_pipeline,
             self._mode,
-            parse_run_config_input(kwargs.get("runConfigData", {})),
+            parse_run_config_input(kwargs.get("runConfigData", {}), raise_on_error=False),
         )
 
 
 class GrapheneRunConfigSchemaOrError(graphene.Union):
     class Meta:
-        from .pipelines.pipeline_errors import GrapheneInvalidSubsetError
-
         types = (
             GrapheneRunConfigSchema,
             GraphenePipelineNotFoundError,
