@@ -1,6 +1,6 @@
 import graphene
 
-from dagster import check
+import dagster._check as check
 from dagster.core.host_representation import ExternalSchedule, ScheduleSelector
 from dagster.core.host_representation.selector import RepositorySelector
 from dagster.core.workspace.permissions import Permissions
@@ -61,6 +61,8 @@ class GrapheneScheduleMutationResult(graphene.Union):
 
 
 class GrapheneStartScheduleMutation(graphene.Mutation):
+    """Enable a schedule to launch runs for a job at a fixed interval."""
+
     Output = graphene.NonNull(GrapheneScheduleMutationResult)
 
     class Arguments:
@@ -76,6 +78,8 @@ class GrapheneStartScheduleMutation(graphene.Mutation):
 
 
 class GrapheneStopRunningScheduleMutation(graphene.Mutation):
+    """Disable a schedule from launching runs for a job."""
+
     Output = graphene.NonNull(GrapheneScheduleMutationResult)
 
     class Arguments:
